@@ -12,7 +12,7 @@ our @EXPORT = qw();
 our %EXPORT_TAGS = ( 'all' => [ qw(rur2words) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require XSLoader;
 XSLoader::load('Lingua::RU::Money::XS', $VERSION);
@@ -42,8 +42,8 @@ money sum in Russian.
 =head1 SYNOPSIS
 
   use Lingua::RU::Money::XS qw(rur2words);
-  print rur2words(123456789012345.67)
-  # outputs "сто двадцать три триллиона четыреста пятьдесят шесть миллиардов семьсот восемьдесят девять миллионов двенадцать тысяч триста сорок пять рублей 67 копеек"
+  print rur2words(123456789012345.00)
+  # outputs "сто двадцать три триллиона четыреста пятьдесят шесть миллиардов семьсот восемьдесят девять миллионов двенадцать тысяч триста сорок пять рублей 00 копеек"
 
 =head1 DESCRIPTION
 
@@ -59,6 +59,34 @@ to I<пять рублей 16 копеек>. The target charset is B<UTF-8>.
 B<Caution>: Current implementation of C<rur2words> follows the Perl philosophy -
 anyway the given argument will be casted to C<double>.
 
+B<Caution>: Due to previous caution there are several constraints, making
+conversion impossible. These constraints divide input values into 4 groups
+listed below
+
+=over 8
+
+=item I<amount less than 0>
+
+Conversion for specified values make no sense. Thus, C<rur2words> croaks for all
+these values.
+
+=item I<amount between 0 and 1e12>
+
+Any value in this range converts correctly with the specified accuracy.
+
+=item I<amount between 1e12 and 1e15>
+
+Due to the lack for significant digits after the radix point for some values in
+this range, kopeck value is calculated inaccurate. It simply is replaced with
+the 0 with the corresponding warning.
+
+=item I<amount greater or equal than 1e15>
+
+Conversion for these values is impossible due to the type overflow. C<rur2words>
+also croaks for all these values.
+
+=back
+
 =back
 
 =cut
